@@ -49,7 +49,7 @@
 		 (repeat :tag "Argument List"
 			 :value ("")
 			 string))
-  :version "21.4"
+  :version "22.1"
   :group 'vc)
 
 (defcustom vc-cvs-register-switches nil
@@ -113,7 +113,7 @@ by these regular expressions."
 Format is according to `format-time-string'.  Only used if
 `vc-cvs-sticky-tag-display' is t."
   :type '(string)
-  :version "21.4"
+  :version "22.1"
   :group 'vc)
 
 (defcustom vc-cvs-sticky-tag-display t
@@ -152,7 +152,7 @@ displayed.  Date and time is displayed for sticky dates.
 
 See also variable `vc-cvs-sticky-date-format-string'."
   :type '(choice boolean function)
-  :version "21.4"
+  :version "22.1"
   :group 'vc)
 
 ;;;
@@ -555,7 +555,9 @@ The changes are between FIRST-VERSION and SECOND-VERSION."
 	       (append (vc-switches nil 'diff) '("/dev/null")))
 	;; Even if it's empty, it's locally modified.
 	1)
-    (let* ((async (and (vc-stay-local-p file) (fboundp 'start-process)))
+    (let* ((async (and (not vc-disable-async-diff)
+                       (vc-stay-local-p file)
+                       (fboundp 'start-process)))
 	   (status (apply 'vc-cvs-command (or buffer "*vc-diff*")
 			  (if async 'async 1)
 			  file "diff"
